fitted.NBKP: Extract NBKP Model Fitted Values

View source: R/fitted_NBKP.R

fitted.NBKPR Documentation

Extract NBKP Model Fitted Values

Description

Compute the posterior fitted values from a fitted NBKP object. For a NBKP object, this returns the posterior mean count from the Gamma‑Negative Binomial conjugate posterior.

Usage

## S3 method for class 'NBKP'
fitted(object, ...)

Arguments

object

An object of class NBKP, typically the result of a call to fit_NBKP.

...

Additional arguments (currently unused).

Details

For a NBKP model, the fitted values correspond to the posterior mean count, computed from the Gamma Kernel Process posterior distribution.

Value

A numeric vector containing posterior mean count estimates at the training inputs.

References

Zhao J, Qing K, Xu J (2025). BKP: An R Package for Beta Kernel Process Modeling. arXiv. https://doi.org/10.48550/arxiv.2508.10447.

Examples


set.seed(123)

# Define true mean function
true_mu_fun <- function(x) {
  exp(sin(x) + 0.5)
}

n <- 30
Xbounds <- matrix(c(-2, 2), nrow = 1)
X <- tgp::lhs(n = n, rect = Xbounds)
true_mu <- true_mu_fun(X)
y <- rnbinom(n, size = 1, mu = true_mu)

# Fit NBKP model
model <- fit_NBKP(X, y, Xbounds = Xbounds)

# Extract fitted values
fitted(model)



NBKP documentation built on June 18, 2026, 1:06 a.m.