View source: R/quantile_NBKP.R
| quantile.NBKP | R Documentation |
Compute posterior quantiles from a fitted NBKP model.
This returns posterior quantiles of the latent mean count from the Gamma posterior distribution.
## S3 method for class 'NBKP'
quantile(x, probs = c(0.025, 0.5, 0.975), ...)
x |
An object of class |
probs |
Numeric vector of probabilities specifying which posterior quantiles to return.
Defaults to |
... |
Additional arguments (currently unused). |
For a NBKP model, posterior quantiles are computed from the Gamma Kernel Process posterior distribution.
A numeric vector (if length(probs) = 1) or numeric matrix (if length(probs) > 1)
of posterior quantiles. Rows correspond to observations, and columns correspond to the requested probabilities.
Zhao J, Qing K, Xu J (2025). BKP: An R Package for Beta Kernel Process Modeling. arXiv. https://doi.org/10.48550/arxiv.2508.10447.
fit_NBKP for model fitting.
set.seed(123)
# Define true mean function
true_mu_fun <- function(x) {
exp(sin(x) + 0.5)
}
n <- 30
Xbounds <- matrix(c(-2, 2), nrow = 1)
X <- tgp::lhs(n = n, rect = Xbounds)
true_mu <- true_mu_fun(X)
y <- rnbinom(n, size = 1, mu = true_mu)
# Fit NBKP model
model <- fit_NBKP(X, y, Xbounds = Xbounds)
# Extract posterior quantiles
quantile(model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.